@@ -10,10 +10,19 @@ from .sendfiles import getpicklezip
 from .sendfiles import sendpicklezip
 from .sendfiles import deploytoprod
 from .sendfiles import nlp
+from .sendfiles import nlpclassify
+from .sendfiles import algoinfo
+from .sendfiles import nlpaudiovideo
+from .sendfiles import nlpocr
+
 
 from .sendfiles import hyperpredictions
 from .sendfiles import tcp_echo_client
 from .sendfiles import retraining
+from .sendfiles import genpdf
+
+from .sendfiles import featureselectionjson
+
 
 from .callmas import dotraining
 from .callmas import dopredictions
