@@ -242,7 +242,7 @@ def retraining(maadstoken,pkey,thefile,autofeature,removeoutliers,hasseasonality
    
    return msg
 
-def uploadcsvfortraining(maadstoken,thefile,autofeature,removeoutliers,hasseasonality,dependentvariable,url,summer,winter,shoulder,trainingpercentage,retrainingdays,retraindeploy,shuffle,theserverlocalname,username='',passw='',company='',email=''):
+def uploadcsvfortraining(maadstoken,thefile,autofeature,removeoutliers,hasseasonality,dependentvariable,url,throttle,summer,winter,shoulder,trainingpercentage,retrainingdays,retraindeploy,shuffle,theserverlocalname,username='',passw='',company='',email=''):
 
    rn=0
    tstr=''
@@ -285,6 +285,7 @@ def uploadcsvfortraining(maadstoken,thefile,autofeature,removeoutliers,hasseason
     'retrainingdays':retrainingdays,
     'retraindeploy':retraindeploy,
     'shuffle':shuffle,
+    'throttle':throttle,
     'maadstoken':maadstoken        
             
    }
@@ -410,9 +411,12 @@ def getpicklezip(maadstoken,pkey,url,localfolder,username='',passw='',company=''
 
     url = "%s/prodfiles/%s_DEPLOYTOPROD.zip" % (url,pkey)
     localname="%s/%s_DEPLOYTOPROD.zip" % (localfolder,pkey)
-    urllib.request.urlretrieve(url, localname)
+    try:
+      urllib.request.urlretrieve(url, localname)
+    except Exception as e:
+      return "ERROR: %s" % e  
     #print(url)
-    return "file retrieved"
+    return "File retrieved: %s FROM %s" % (localname,url)
 
 
 def sendpicklezip(maadstoken,pkey,url,localname,username='',passw='',company='',email=''):
@@ -420,27 +424,33 @@ def sendpicklezip(maadstoken,pkey,url,localname,username='',passw='',company='',
     data = {'mode':'uploads', 'username':username, 'password':passw,'company':company,'email':email,'pkey':pkey,'maadstoken':maadstoken}
     
     files = {'file': open(localname, 'rb')}
-    r = requests.post(url, data=data, files=files)
-    return r.text
+    try:
+      r = requests.post(url, data=data, files=files)
+    except Exception as e:
+      return "ERROR: %s" % e  
+    return "File Sent: %s TO %s" % (localname,url)
     
 def deploytoprod(maadstoken,pkey,url,localname='',ftpserver='',ftpuser='',ftppass='',username='',passw='',company='',email=''):
 
     data = {'mode':'deploy', 'username':username, 'password':passw,'company':company,'email':email,'localname':localname,'pkey':pkey,'maadstoken':maadstoken,'ftpserver':ftpserver,'ftpuser':ftpuser,'ftppass':ftppass}
 
     #print(prodserverurl)
+    bn=''
 
-    
-    if len(localname)>0:
-        bn=os.path.basename(localname)
-        data = {'mode':'deploy', 'username':username, 'password':passw,'company':company,'email':email,'localname':bn,'maadstoken':maadstoken,'pkey':pkey,'ftpserver':ftpserver,'ftpuser':ftpuser,'ftppass':ftppass}        
-        files = {'file': open(localname, 'rb')}
-        r = requests.post(url, data=data, files=files)
-    else:
-        bn="%s_DEPLOYTOPROD.zip" % (pkey)
-        data = {'mode':'deploy', 'username':username, 'password':passw,'company':company,'email':email,'localname':localname,'maadstoken':maadstoken,'pkey':pkey,'ftpserver':ftpserver,'ftpuser':ftpuser,'ftppass':ftppass}                
-        r = requests.post(url, data=data)
- #   print(r.text)    
-    return r.text
+    try: 
+        if len(localname)>0:
+            bn=os.path.basename(localname)
+            data = {'mode':'deploy', 'username':username, 'password':passw,'company':company,'email':email,'localname':bn,'maadstoken':maadstoken,'pkey':pkey,'ftpserver':ftpserver,'ftpuser':ftpuser,'ftppass':ftppass}        
+            files = {'file': open(localname, 'rb')}
+            r = requests.post(url, data=data, files=files)
+        else:
+            bn="%s_DEPLOYTOPROD.zip" % (pkey)
+            data = {'mode':'deploy', 'username':username, 'password':passw,'company':company,'email':email,'localname':localname,'maadstoken':maadstoken,'pkey':pkey,'ftpserver':ftpserver,'ftpuser':ftpuser,'ftppass':ftppass}                
+            r = requests.post(url, data=data)
+    except Exception as e:
+      return "ERROR: %s" % e  
+    return "File Deployed: %s TO %s" % (bn,url)
+#    return r.text
 
 def nlp(maadstoken,url,buffer,theserverfolder='',detail=20,maxkeywords=10,username='',passw='',company='',email=''):
     isurl=0
@@ -506,7 +516,7 @@ def nlpocr(maadstoken,maads_rest_url,thefile='',theserverfolder='',username='',p
     return r.text
     
 #csvfile,iscategory,maads_rest_url,trainingpercentage,retrainingdays,retraindeploy
-def nlpclassify(maadstoken,iscategory,maads_rest_url,thefile='',theserverlocalname='',csvonly=0,username='',trainingpercentage=75,retrainingdays=0,retraindeploy=0,passw='',company='',email=''):
+def nlpclassify(maadstoken,iscategory,maads_rest_url,thefile='',theserverlocalname='',throttle=-1,csvonly=0,username='',trainingpercentage=75,retrainingdays=0,retraindeploy=0,passw='',company='',email=''):
     print("Please wait..this could take several minutes")
     tstr=''
     rn=0
@@ -560,6 +570,7 @@ def nlpclassify(maadstoken,iscategory,maads_rest_url,thefile='',theserverlocalna
         'email': email,
         'filename':filename,
         'csvonly':csvonly,
+        'throttle':throttle,
         'maadstoken':maadstoken,     
     #'dependentvariable': dependentvariable,
         'title':'Do NLP Classify'
